.. webapi-error::
   :title: Extension Already Installed
   :instance: djblets.webapi.errors.EXTENSION_INSTALLED

   A request to install an extension failed, because the extension was
   already installed.
